@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Fcntl qw(:flock);
 use Storable::AMF0;
-our $VERSION = '0.27';
+our $VERSION = '0.30';
 
 require Exporter;
 our @ISA = qw(Exporter);
@@ -14,7 +14,7 @@ our @ISA = qw(Exporter);
 # Do not simply export all your public functions/methods/constants.
 
 our %EXPORT_TAGS = ( 'all' => [ qw(
-	freeze thaw	dclone retrieve lock_retrieve lock_store lock_nstore store
+	freeze thaw	dclone retrieve lock_retrieve lock_store lock_nstore store ref_lost_memory ref_destroy
 ) ] );
 
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
@@ -112,6 +112,14 @@ And some cases faster then Storable( for me always)
 =item dclone $file
   --- Deep cloning data structure
 
+=item ref_destroy $obj
+  --- Deep decloning data structure
+  --- safely destroy cloned object or any object 
+
+=item ref_lost_memory $obj
+  --- test if object contain lost memory fragments inside.
+  (Example do { my $a = []; @$a=$a; $a})
+
 =back
 
 =head1 NOTICE
